@@ -1,4 +1,5 @@
 # (C) Copyright 2015,2016 Hewlett Packard Enterprise Development LP
+# Copyright 2017 Fujitsu LIMITED
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,23 +14,33 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import json
 import requests
+import ujson as json
 
+from debtcollector import removals
+from oslo_config import cfg
+
+from monasca_notification.common import utils
 from monasca_notification.plugins import abstract_notifier
 
+CONF = cfg.CONF
+
 
 class WebhookNotifier(abstract_notifier.AbstractNotifier):
+
+    type = 'webhook'
+
     def __init__(self, log):
+        super(WebhookNotifier, self).__init__()
         self._log = log
 
+    @removals.remove(
+        message='Configuration of notifier is available through oslo.cfg',
+        version='1.9.0',
+        removal_version='3.0.0'
+    )
     def config(self, config_dict):
-        self._config = {'timeout': 5}
-        self._config.update(config_dict)
-
-    @property
-    def type(self):
-        return "webhook"
+        pass
 
     @property
     def statsd_name(self):
@@ -53,6 +64,13 @@ class WebhookNotifier(abstract_notifier.AbstractNotifier):
 
         headers = {'content-type': 'application/json'}
 
+        # Checks if keystone authentication is enabled and adds authentication
+        # token to the request headers
+        if CONF.keystone.auth_required:
+            auth_token = utils.get_auth_token()
+            headers = {'content-type': 'application/json',
+                       'X-Auth-Token': auth_token}
+
         url = notification.address
 
         try:
@@ -60,7 +78,7 @@ class WebhookNotifier(abstract_notifier.AbstractNotifier):
             result = requests.post(url=url,
                                    data=json.dumps(body),
                                    headers=headers,
-                                   timeout=self._config['timeout'])
+                                   timeout=CONF.webhook_notifier.timeout)
 
             if result.status_code in range(200, 300):
                 self._log.info("Notification successfully posted.")
@@ -72,3 +90,19 @@ class WebhookNotifier(abstract_notifier.AbstractNotifier):
         except Exception:
             self._log.exception("Error trying to post on URL {}".format(url))
             return False
+
+webhook_notifier_group = cfg.OptGroup(name='%s_notifier' % WebhookNotifier.type)
+webhook_notifier_opts = [
+    cfg.IntOpt(name='timeout', default=5, min=1)
+]
+
+
+def register_opts(conf):
+    conf.register_group(webhook_notifier_group)
+    conf.register_opts(webhook_notifier_opts, group=webhook_notifier_group)
+
+
+def list_opts():
+    return {
+        webhook_notifier_group: webhook_notifier_opts
+    }
