@@ -13,8 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import logging
+from oslo_log import log as logging
 
+from monasca_notification.common.repositories import exceptions as exc
 from monasca_notification.common.utils import get_db_repo
 from monasca_notification.common.utils import get_statsd_client
 from monasca_notification.types import notifiers
@@ -24,27 +25,44 @@ log = logging.getLogger(__name__)
 
 class NotificationProcessor(object):
 
-    def __init__(self, config):
-        self.statsd = get_statsd_client(config)
+    def __init__(self):
+        self.statsd = get_statsd_client()
         notifiers.init(self.statsd)
-        notifiers.load_plugins(config['notification_types'])
-        notifiers.config(config['notification_types'])
-        self._db_repo = get_db_repo(config)
+
+        notifiers.load_plugins()
+        notifiers.config()
+
+        self._db_repo = get_db_repo()
         self.insert_configured_plugins()
 
+    def _remaining_plugin_types(self):
+        configured_plugin_types = notifiers.enabled_notifications()
+        persisted_plugin_types = self._db_repo.fetch_notification_method_types()
+
+        return set(configured_plugin_types) - set(persisted_plugin_types)
+
     def insert_configured_plugins(self):
         """Persists configured plugin types in DB
              For each notification type configured add it in db, if it is not there
         """
-        configured_plugin_types = notifiers.enabled_notifications()
+        remaining_plugin_types = self._remaining_plugin_types()
 
-        persisted_plugin_types = self._db_repo.fetch_notification_method_types()
-        remaining_plugin_types = set(configured_plugin_types) - set(persisted_plugin_types)
-
-        if remaining_plugin_types:
-            log.info("New plugins detected: Adding new notification types {} to database"
-                     .format(remaining_plugin_types))
-            self._db_repo.insert_notification_method_types(remaining_plugin_types)
+        max_retry = len(remaining_plugin_types)
+        retry_count = 0
+        while remaining_plugin_types:
+            retry_count = retry_count + 1
+            try:
+                log.info("New plugins detected: Adding new notification types %s to database",
+                         remaining_plugin_types)
+                self._db_repo.insert_notification_method_types(remaining_plugin_types)
+            except exc.DatabaseException as e:
+                # There is a possibility the other process has already registered the type.
+                remaining_plugin_types = self._remaining_plugin_types()
+                if remaining_plugin_types and (retry_count >= max_retry):
+                    log.exception("Couldn't insert notification types %s", e)
+                    raise e
+                else:
+                    log.debug("Plugin already exists. Ignore exception")
 
     def send(self, notifications):
         """Send the notifications
