@@ -16,15 +16,18 @@
 # limitations under the License.
 
 import base64
+import datetime
 import email.header
-import mock
 import smtplib
 import socket
 import time
 
+import mock
 import six
 
-import datetime
+from monasca_notification.notification import Notification
+from monasca_notification.plugins import email_notifier
+from tests import base
 
 if six.PY2:
     import urlparse
@@ -32,10 +35,6 @@ else:
     from urllib import parse
     from urllib.parse import urlparse
 
-from monasca_notification.notification import Notification
-from monasca_notification.plugins import email_notifier
-from tests import base
-
 UNICODE_CHAR = six.unichr(2344)
 UNICODE_CHAR_ENCODED = UNICODE_CHAR.encode("utf-8")
 
@@ -143,7 +142,8 @@ class TestEmail(base.PluginTestCase):
 
         alarm_dict = alarm(metric)
 
-        notification = Notification(0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
+        notification = Notification(0, 'email', 'email notification',
+                                    'me@here.com', 0, 0, alarm_dict)
 
         self.trap.append(email.send_notification(notification))
 
@@ -267,7 +267,8 @@ class TestEmail(base.PluginTestCase):
 
         alarm_dict = alarm(metrics)
 
-        notification = Notification(0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
+        notification = Notification(0, 'email', 'email notification',
+                                    'me@here.com', 0, 0, alarm_dict)
 
         self.trap.append(email.send_notification(notification))
 
@@ -313,7 +314,8 @@ class TestEmail(base.PluginTestCase):
 
         alarm_dict = alarm(metrics)
 
-        notification = Notification(0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
+        notification = Notification(0, 'email', 'email notification',
+                                    'me@here.com', 0, 0, alarm_dict)
 
         email_result = email.send_notification(notification)
 
@@ -355,7 +357,8 @@ class TestEmail(base.PluginTestCase):
 
         alarm_dict = alarm(metrics)
 
-        notification = Notification(0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
+        notification = Notification(0, 'email', 'email notification',
+                                    'me@here.com', 0, 0, alarm_dict)
 
         self.trap.append(email.send_notification(notification))
 
@@ -395,7 +398,8 @@ class TestEmail(base.PluginTestCase):
 
         alarm_dict = alarm(metrics)
 
-        notification = Notification(0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
+        notification = Notification(0, 'email', 'email notification',
+                                    'me@here.com', 0, 0, alarm_dict)
 
         self.trap.append(email.send_notification(notification))
 
@@ -435,7 +439,8 @@ class TestEmail(base.PluginTestCase):
 
         alarm_dict = alarm(metrics)
 
-        notification = Notification(0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
+        notification = Notification(0, 'email', 'email notification',
+                                    'me@here.com', 0, 0, alarm_dict)
 
         self.trap.append(email.send_notification(notification))
 
